/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'en-gb', {
	bold: 'Bold',
	italic: 'Italic',
	strike: 'Strike Through',
	subscript: 'Subscript',
	superscript: 'Superscript',
	underline: 'Underline'
} );
