{% extends "admin/index.html" %}


{% block extrahead %}
    {{ block.super }}
    {% include "admin/cms/scripts.html" %}
{% endblock %}

{% block sidebar %}
    <div id="content-related">
        <div class="module" id="recent-actions-module">
            <h4 class="italic-title">Sitemap</h4>
            <noscript>
                <p>Please turn on javascript to activate the sitemap.</p>
            </noscript>
        </div>
        <script>
            (function($) {
                $("#recent-actions-module").cms("sitemap");
            }(django.jQuery));
        </script>
    </div>
{% endblock %}
