/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'cy', {
	bold: 'Bras',
	italic: 'Italig',
	strike: 'Llinell Trwyddo',
	subscript: 'Is-sgript',
	superscript: 'Uwchsgript',
	underline: 'Tanlinellu'
} );
