/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'af', {
	label: 'Opmaak',
	panelTitle: 'Opmaak',
	tag_address: 'Adres',
	tag_div: 'Normaal (DIV)',
	tag_h1: 'Opskrif 1',
	tag_h2: 'Opskrif 2',
	tag_h3: 'Opskrif 3',
	tag_h4: 'Opskrif 4',
	tag_h5: 'Opskrif 5',
	tag_h6: 'Opskrif 6',
	tag_p: 'Normaal',
	tag_pre: 'Opgemaak'
} );
