/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'km', {
	border: 'ទំហំ​បន្ទាត់​ស៊ុម',
	caption: 'ចំណងជើង',
	cell: {
		menu: 'ក្រឡា',
		insertBefore: 'បញ្ចូល​ក្រឡា​ពីមុខ',
		insertAfter: 'បញ្ចូល​ក្រឡា​ពី​ក្រោយ',
		deleteCell: 'លុប​ក្រឡា',
		merge: 'បញ្ចូល​ក្រឡា​ចូល​គ្នា',
		mergeRight: 'បញ្ចូល​គ្នា​ខាង​ស្ដាំ',
		mergeDown: 'បញ្ចូល​គ្នា​ចុះ​ក្រោម',
		splitHorizontal: 'ពុះ​ក្រឡា​ផ្ដេក',
		splitVertical: 'ពុះ​ក្រឡា​បញ្ឈរ',
		title: 'លក្ខណៈ​ក្រឡា',
		cellType: 'ប្រភេទ​ក្រឡា',
		rowSpan: 'ចំនួន​ជួរ​ដេក​លាយ​ចូល​គ្នា',
		colSpan: 'ចំនួន​ជួរ​ឈរ​លាយ​ចូល​គ្នា',
		wordWrap: 'រុំ​ពាក្យ',
		hAlign: 'ការ​តម្រឹម​ផ្ដេក',
		vAlign: 'ការ​តម្រឹម​បញ្ឈរ',
		alignBaseline: 'ខ្សែ​បន្ទាត់​គោល',
		bgColor: 'ពណ៌​ផ្ទៃ​ក្រោយ',
		borderColor: 'ពណ៌​បន្ទាត់​ស៊ុម',
		data: 'ទិន្នន័យ',
		header: 'ក្បាល',
		yes: 'ព្រម',
		no: 'ទេ',
		invalidWidth: 'ទទឹង​ក្រឡា​ត្រូវ​តែ​ជា​លេខ។',
		invalidHeight: 'កម្ពស់​ក្រឡា​ត្រូវ​តែ​ជា​លេខ។',
		invalidRowSpan: 'ចំនួន​ជួរ​ដេក​លាយ​ចូល​គ្នា​ត្រូវ​តែ​ជា​លេខ​ទាំង​អស់។',
		invalidColSpan: 'ចំនួន​ជួរ​ឈរ​លាយ​ចូល​គ្នា​ត្រូវ​តែ​ជា​លេខ​ទាំង​អស់។',
		chooseColor: 'រើស'
	},
	cellPad: 'ចន្លោះ​ក្រឡា',
	cellSpace: 'គម្លាត​ក្រឡា',
	column: {
		menu: 'ជួរ​ឈរ',
		insertBefore: 'បញ្ចូល​ជួរ​ឈរ​ពីមុខ',
		insertAfter: 'បញ្ចូល​ជួរ​ឈរ​ពី​ក្រោយ',
		deleteColumn: 'លុប​ជួរ​ឈរ'
	},
	columns: 'ជួរឈរ',
	deleteTable: 'លុប​តារាង',
	headers: 'ក្បាល',
	headersBoth: 'ទាំង​ពីរ',
	headersColumn: 'ជួរ​ឈរ​ដំបូង',
	headersNone: 'មិន​មាន',
	headersRow: 'ជួរ​ដេក​ដំបូង',
	invalidBorder: 'ទំហំ​បន្ទាត់​ស៊ុម​ត្រូវ​តែ​ជា​លេខ។',
	invalidCellPadding: 'ចន្លោះ​ក្រឡា​ត្រូវ​តែជា​លេខ​វិជ្ជមាន។',
	invalidCellSpacing: 'គម្លាត​ក្រឡា​ត្រូវ​តែ​ជា​លេខ​វិជ្ជមាន។',
	invalidCols: 'ចំនួន​ជួរ​ឈរ​ត្រូវ​តែ​ជា​លេខ​ធំ​ជាង 0។',
	invalidHeight: 'កម្ពស់​តារាង​ត្រូវ​តែ​ជា​លេខ',
	invalidRows: 'ចំនួន​ជួរ​ដេក​ត្រូវ​តែ​ជា​លេខ​ធំ​ជាង 0។',
	invalidWidth: 'ទទឹង​តារាង​ត្រូវ​តែ​ជា​លេខ។',
	menu: 'លក្ខណៈ​តារាង',
	row: {
		menu: 'ជួរ​ដេក',
		insertBefore: 'បញ្ចូល​ជួរ​ដេក​ពីមុខ',
		insertAfter: 'បញ្ចូល​ជួរ​ដេក​ពី​ក្រោយ',
		deleteRow: 'លុប​ជួរ​ដេក'
	},
	rows: 'ជួរ​ដេក',
	summary: 'សេចក្តី​សង្ខេប',
	title: 'លក្ខណៈ​តារាង',
	toolbar: 'តារាង',
	widthPc: 'ភាគរយ',
	widthPx: 'ភីកសែល',
	widthUnit: 'ឯកតា​ទទឹង'
} );
