/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'ku', {
	bold: 'قەڵەو',
	italic: 'لار',
	strike: 'لێدان',
	subscript: 'ژێرنووس',
	superscript: 'سەرنووس',
	underline: 'ژێرهێڵ'
} );
