/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'el', {
	toolbarCollapse: 'Σύμπτυξη Εργαλειοθήκης',
	toolbarExpand: 'Ανάπτυξη Εργαλειοθήκης',
	toolbarGroups: {
		document: 'Έγγραφο',
		clipboard: 'Πρόχειρο/Αναίρεση',
		editing: 'Επεξεργασία',
		forms: 'Φόρμες',
		basicstyles: 'Βασικά Στυλ',
		paragraph: 'Παράγραφος',
		links: 'Σύνδεσμοι',
		insert: 'Εισαγωγή',
		styles: 'Στυλ',
		colors: 'Χρώματα',
		tools: 'Εργαλεία'
	},
	toolbars: 'Εργαλειοθήκες επεξεργαστή'
} );
