/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'hu', {
	toolbarCollapse: 'Eszköztár összecsukása',
	toolbarExpand: 'Eszköztár szétnyitása',
	toolbarGroups: {
		document: 'Dokumentum',
		clipboard: 'Vágólap/Visszavonás',
		editing: 'Szerkesztés',
		forms: 'Űrlapok',
		basicstyles: 'Alapstílusok',
		paragraph: 'Bekezdés',
		links: 'Hivatkozások',
		insert: 'Beszúrás',
		styles: 'Stílusok',
		colors: 'Színek',
		tools: 'Eszközök'
	},
	toolbars: 'Szerkesztő Eszköztár'
} );
