/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'sr', {
	border: 'Величина оквира',
	caption: 'Наслов табеле',
	cell: {
		menu: 'Cell',
		insertBefore: 'Insert Cell Before',
		insertAfter: 'Insert Cell After',
		deleteCell: 'Обриши ћелије',
		merge: 'Спој ћелије',
		mergeRight: 'Merge Right',
		mergeDown: 'Merge Down',
		splitHorizontal: 'Split Cell Horizontally',
		splitVertical: 'Split Cell Vertically',
		title: 'Cell Properties',
		cellType: 'Cell Type',
		rowSpan: 'Rows Span',
		colSpan: 'Columns Span',
		wordWrap: 'Word Wrap',
		hAlign: 'Horizontal Alignment',
		vAlign: 'Vertical Alignment',
		alignBaseline: 'Baseline',
		bgColor: 'Background Color',
		borderColor: 'Border Color',
		data: 'Data',
		header: 'Header',
		yes: 'Yes',
		no: 'No',
		invalidWidth: 'Cell width must be a number.',
		invalidHeight: 'Cell height must be a number.',
		invalidRowSpan: 'Rows span must be a whole number.',
		invalidColSpan: 'Columns span must be a whole number.',
		chooseColor: 'Choose'
	},
	cellPad: 'Размак ћелија',
	cellSpace: 'Ћелијски простор',
	column: {
		menu: 'Column',
		insertBefore: 'Insert Column Before',
		insertAfter: 'Insert Column After',
		deleteColumn: 'Обриши колоне'
	},
	columns: 'Kолона',
	deleteTable: 'Обриши таблу',
	headers: 'Поглавља',
	headersBoth: 'Оба',
	headersColumn: 'Прва колона',
	headersNone: 'None',
	headersRow: 'Први ред',
	invalidBorder: 'Величина ивице треба да буде цифра.',
	invalidCellPadding: 'Пуњење ћелије треба да буде позитивна цифра.',
	invalidCellSpacing: 'Размак ћелије треба да буде позитивна цифра.',
	invalidCols: 'Број колона треба да буде цифра већа од 0.',
	invalidHeight: 'Висина табеле треба да буде цифра.',
	invalidRows: 'Број реда треба да буде цифра већа од 0.',
	invalidWidth: 'Ширина табеле треба да буде цифра.',
	menu: 'Особине табеле',
	row: {
		menu: 'Row',
		insertBefore: 'Insert Row Before',
		insertAfter: 'Insert Row After',
		deleteRow: 'Обриши редове'
	},
	rows: 'Редова',
	summary: 'Резиме',
	title: 'Особине табеле',
	toolbar: 'Табела',
	widthPc: 'процената',
	widthPx: 'пиксела',
	widthUnit: 'јединица ширине'
} );
