/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'hr', {
	toolbarCollapse: 'Smanji alatnu traku',
	toolbarExpand: 'Proširi alatnu traku',
	toolbarGroups: {
		document: 'Dokument',
		clipboard: 'Međuspremnik/Poništi',
		editing: 'Uređivanje',
		forms: 'Forme',
		basicstyles: 'Osnovni stilovi',
		paragraph: 'Paragraf',
		links: 'Veze',
		insert: 'Umetni',
		styles: 'Stilovi',
		colors: 'Boje',
		tools: 'Alatke'
	},
	toolbars: 'Alatne trake uređivača teksta'
} );
