/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastetext', 'ug', {
	button: 'پىچىمى يوق تېكىست سۈپىتىدە چاپلا',
	title: 'پىچىمى يوق تېكىست سۈپىتىدە چاپلا'
} );
