/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'pt-br', {
	options: 'Opções de Caractere Especial',
	title: 'Selecione um Caractere Especial',
	toolbar: 'Inserir Caractere Especial'
} );
