/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'ar', {
	options: 'خيارات الأحرف الخاصة',
	title: 'اختر حرف خاص',
	toolbar: 'إدراج  حرف خاص'
} );
