/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sr', {
	acccessKey: 'Приступни тастер',
	advanced: 'Напредни тагови',
	advisoryContentType: 'Advisory врста садржаја',
	advisoryTitle: 'Advisory наслов',
	anchor: {
		toolbar: 'Унеси/измени сидро',
		menu: 'Особине сидра',
		title: 'Особине сидра',
		name: 'Име сидра',
		errorName: 'Молимо Вас да унесете име сидра',
		remove: 'Remove Anchor'
	},
	anchorId: 'Пo Ид-jу елемента',
	anchorName: 'По називу сидра',
	charset: 'Linked Resource Charset',
	cssClasses: 'Stylesheet класе',
	emailAddress: 'Адреса електронске поште',
	emailBody: 'Садржај поруке',
	emailSubject: 'Наслов',
	id: 'Ид',
	info: 'Линк инфо',
	langCode: 'Смер језика',
	langDir: 'Смер језика',
	langDirLTR: 'С лева на десно (LTR)',
	langDirRTL: 'С десна на лево (RTL)',
	menu: 'Промени линк',
	name: 'Назив',
	noAnchors: '(Нема доступних сидра)',
	noEmail: 'Откуцајте адресу електронске поште',
	noUrl: 'Унесите УРЛ линка',
	other: '<друго>',
	popupDependent: 'Зависно (Netscape)',
	popupFeatures: 'Могућности искачућег прозора',
	popupFullScreen: 'Приказ преко целог екрана (ИE)',
	popupLeft: 'Од леве ивице екрана (пиксела)',
	popupLocationBar: 'Локација',
	popupMenuBar: 'Контекстни мени',
	popupResizable: 'Величина се мења',
	popupScrollBars: 'Скрол бар',
	popupStatusBar: 'Статусна линија',
	popupToolbar: 'Toolbar',
	popupTop: 'Од врха екрана (пиксела)',
	rel: 'Однос',
	selectAnchor: 'Одабери сидро',
	styles: 'Стил',
	tabIndex: 'Таб индекс',
	target: 'Meтa',
	targetFrame: '<оквир>',
	targetFrameName: 'Назив одредишног фрејма',
	targetPopup: '<искачући прозор>',
	targetPopupName: 'Назив искачућег прозора',
	title: 'Линк',
	toAnchor: 'Сидро на овој страници',
	toEmail: 'Eлектронска пошта',
	toUrl: 'УРЛ',
	toolbar: 'Унеси/измени линк',
	type: 'Врста линка',
	unlink: 'Уклони линк',
	upload: 'Пошаљи'
} );
