/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'th', {
	bold: 'ตัวหนา',
	italic: 'ตัวเอียง',
	strike: 'ตัวขีดเส้นทับ',
	subscript: 'ตัวห้อย',
	superscript: 'ตัวยก',
	underline: 'ตัวขีดเส้นใต้'
} );
