/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'format', 'he', {
	label: 'עיצוב',
	panelTitle: 'עיצוב',
	tag_address: 'כתובת',
	tag_div: 'נורמלי (DIV)',
	tag_h1: 'כותרת',
	tag_h2: 'כותרת 2',
	tag_h3: 'כותרת 3',
	tag_h4: 'כותרת 4',
	tag_h5: 'כותרת 5',
	tag_h6: 'כותרת 6',
	tag_p: 'נורמלי',
	tag_pre: 'קוד'
} );
