{% extends "admin/change_form.html" %}

{% block object-tools-items %}
    <li>
        <a href="history/" class="historylink">
            <i class="icon-time icon-alpha75"></i>History
        </a>
    </li>
    {% if has_absolute_url %}
        <li>
            <a href="{{original.get_absolute_url}}?preview=1" class="viewsitelink">
                <i class="icon-eye-open icon-alpha75"></i>
                View on site
            </a>
        </li>
    {% endif%}
{% endblock %}
