/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'sr-latn', {
	confirmCleanup: 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
	error: 'It was not possible to clean up the pasted data due to an internal error', // MISSING
	title: 'Zalepi iz Worda',
	toolbar: 'Zalepi iz Worda'
} );
