/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'stylescombo', 'zh', {
	label: '樣式',
	panelTitle: '格式化樣式',
	panelTitle1: '區塊樣式',
	panelTitle2: '內嵌樣式',
	panelTitle3: '物件樣式'
} );
