/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'eu', {
	border: 'Ertzaren Zabalera',
	caption: 'Epigrafea',
	cell: {
		menu: 'Gelaxka',
		insertBefore: 'Txertatu Gelaxka Aurretik',
		insertAfter: 'Txertatu Gelaxka Ostean',
		deleteCell: 'Kendu Gelaxkak',
		merge: 'Batu Gelaxkak',
		mergeRight: 'Elkartu Eskumara',
		mergeDown: 'Elkartu Behera',
		splitHorizontal: 'Banatu Gelaxkak Horizontalki',
		splitVertical: 'Banatu Gelaxkak Bertikalki',
		title: 'Gelaxken Ezaugarriak',
		cellType: 'Gelaxka Mota',
		rowSpan: 'Hedatutako Lerroak',
		colSpan: 'Hedatutako Zutabeak',
		wordWrap: 'Itzulbira',
		hAlign: 'Lerrokatze Horizontala',
		vAlign: 'Lerrokatze Bertikala',
		alignBaseline: 'Oinarri-lerroan',
		bgColor: 'Fondoaren Kolorea',
		borderColor: 'Ertzaren Kolorea',
		data: 'Data',
		header: 'Goiburua',
		yes: 'Bai',
		no: 'Ez',
		invalidWidth: 'Gelaxkaren zabalera zenbaki bat izan behar da.',
		invalidHeight: 'Gelaxkaren altuera zenbaki bat izan behar da.',
		invalidRowSpan: 'Lerroen hedapena zenbaki osoa izan behar da.',
		invalidColSpan: 'Zutabeen hedapena zenbaki osoa izan behar da.',
		chooseColor: 'Choose'
	},
	cellPad: 'Gelaxken betegarria',
	cellSpace: 'Gelaxka arteko tartea',
	column: {
		menu: 'Zutabea',
		insertBefore: 'Txertatu Zutabea Aurretik',
		insertAfter: 'Txertatu Zutabea Ostean',
		deleteColumn: 'Ezabatu Zutabeak'
	},
	columns: 'Zutabeak',
	deleteTable: 'Ezabatu Taula',
	headers: 'Goiburuak',
	headersBoth: 'Biak',
	headersColumn: 'Lehen zutabea',
	headersNone: 'Bat ere ez',
	headersRow: 'Lehen lerroa',
	invalidBorder: 'Ertzaren tamaina zenbaki bat izan behar da.',
	invalidCellPadding: 'Gelaxken betegarria zenbaki bat izan behar da.',
	invalidCellSpacing: 'Gelaxka arteko tartea zenbaki bat izan behar da.',
	invalidCols: 'Zutabe kopurua 0 baino handiagoa den zenbakia izan behar da.',
	invalidHeight: 'Taularen altuera zenbaki bat izan behar da.',
	invalidRows: 'Lerro kopurua 0 baino handiagoa den zenbakia izan behar da.',
	invalidWidth: 'Taularen zabalera zenbaki bat izan behar da.',
	menu: 'Taularen Ezaugarriak',
	row: {
		menu: 'Lerroa',
		insertBefore: 'Txertatu Lerroa Aurretik',
		insertAfter: 'Txertatu Lerroa Ostean',
		deleteRow: 'Ezabatu Lerroak'
	},
	rows: 'Lerroak',
	summary: 'Laburpena',
	title: 'Taularen Ezaugarriak',
	toolbar: 'Taula',
	widthPc: 'ehuneko',
	widthPx: 'pixel',
	widthUnit: 'zabalera unitatea'
} );
