/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sl', {
	acccessKey: 'Dostopno Geslo',
	advanced: 'Napredno',
	advisoryContentType: 'Predlagani tip vsebine (content-type)',
	advisoryTitle: 'Predlagani naslov',
	anchor: {
		toolbar: 'Vstavi/uredi zaznamek',
		menu: 'Lastnosti zaznamka',
		title: 'Lastnosti zaznamka',
		name: 'Ime zaznamka',
		errorName: 'Prosim vnesite ime zaznamka',
		remove: 'Remove Anchor'
	},
	anchorId: 'Po ID-ju elementa',
	anchorName: 'Po imenu zaznamka',
	charset: 'Kodna tabela povezanega vira',
	cssClasses: 'Razred stilne predloge',
	emailAddress: 'Elektronski naslov',
	emailBody: 'Vsebina sporočila',
	emailSubject: 'Predmet sporočila',
	id: 'Id',
	info: 'Podatki o povezavi',
	langCode: 'Smer jezika',
	langDir: 'Smer jezika',
	langDirLTR: 'Od leve proti desni (LTR)',
	langDirRTL: 'Od desne proti levi (RTL)',
	menu: 'Uredi povezavo',
	name: 'Ime',
	noAnchors: '(V tem dokumentu ni zaznamkov)',
	noEmail: 'Vnesite elektronski naslov',
	noUrl: 'Vnesite URL povezave',
	other: '<drug>',
	popupDependent: 'Podokno (Netscape)',
	popupFeatures: 'Značilnosti pojavnega okna',
	popupFullScreen: 'Celozaslonska slika (IE)',
	popupLeft: 'Lega levo',
	popupLocationBar: 'Naslovna vrstica',
	popupMenuBar: 'Menijska vrstica',
	popupResizable: 'Spremenljive velikosti',
	popupScrollBars: 'Drsniki',
	popupStatusBar: 'Vrstica stanja',
	popupToolbar: 'Orodna vrstica',
	popupTop: 'Lega na vrhu',
	rel: 'Odnos',
	selectAnchor: 'Izberi zaznamek',
	styles: 'Slog',
	tabIndex: 'Številka tabulatorja',
	target: 'Cilj',
	targetFrame: '<okvir>',
	targetFrameName: 'Ime ciljnega okvirja',
	targetPopup: '<pojavno okno>',
	targetPopupName: 'Ime pojavnega okna',
	title: 'Povezava',
	toAnchor: 'Zaznamek na tej strani',
	toEmail: 'Elektronski naslov',
	toUrl: 'URL',
	toolbar: 'Vstavi/uredi povezavo',
	type: 'Vrsta povezave',
	unlink: 'Odstrani povezavo',
	upload: 'Prenesi'
} );
