/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'pt', {
	anchor: ' Inserir/Editar Âncora',
	flash: 'Animação Flash',
	hiddenfield: 'Campo oculto',
	iframe: 'IFrame',
	unknown: 'Objeto Desconhecido'
} );
