/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'he', {
	anchor: 'עוגן',
	flash: 'סרטון פלאש',
	hiddenfield: 'שדה חבוי',
	iframe: 'חלון פנימי (iframe)',
	unknown: 'אובייקט לא ידוע'
} );
