/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'af', {
	border: 'Randbreedte',
	caption: 'Naam',
	cell: {
		menu: 'Sel',
		insertBefore: 'Voeg sel in voor',
		insertAfter: 'Voeg sel in na',
		deleteCell: 'Verwyder sel',
		merge: 'Voeg selle saam',
		mergeRight: 'Voeg saam na regs',
		mergeDown: 'Voeg saam ondertoe',
		splitHorizontal: 'Splits sel horisontaal',
		splitVertical: 'Splits sel vertikaal',
		title: 'Sel eienskappe',
		cellType: 'Sel tipe',
		rowSpan: 'Omspan rye',
		colSpan: 'Omspan kolomme',
		wordWrap: 'Woord terugloop',
		hAlign: 'Horisontale oplyning',
		vAlign: 'Vertikale oplyning',
		alignBaseline: 'Basislyn',
		bgColor: 'Agtergrondkleur',
		borderColor: 'Randkleur',
		data: 'Inhoud',
		header: 'Opskrif',
		yes: 'Ja',
		no: 'Nee',
		invalidWidth: 'Selbreedte moet \'n getal wees.',
		invalidHeight: 'Selhoogte moet \'n getal wees.',
		invalidRowSpan: 'Omspan rye moet \'n heelgetal wees.',
		invalidColSpan: 'Omspan kolomme moet \'n heelgetal wees.',
		chooseColor: 'Kies'
	},
	cellPad: 'Sel-spasie',
	cellSpace: 'Sel-afstand',
	column: {
		menu: 'Kolom',
		insertBefore: 'Voeg kolom in voor',
		insertAfter: 'Voeg kolom in na',
		deleteColumn: 'Verwyder kolom'
	},
	columns: 'Kolomme',
	deleteTable: 'Verwyder tabel',
	headers: 'Opskrifte',
	headersBoth: 'Beide    ',
	headersColumn: 'Eerste kolom',
	headersNone: 'Geen',
	headersRow: 'Eerste ry',
	invalidBorder: 'Randbreedte moet \'n getal wees.',
	invalidCellPadding: 'Sel-spasie moet \'n getal wees.',
	invalidCellSpacing: 'Sel-afstand moet \'n getal wees.',
	invalidCols: 'Aantal kolomme moet \'n getal groter as 0 wees.',
	invalidHeight: 'Tabelhoogte moet \'n getal wees.',
	invalidRows: 'Aantal rye moet \'n getal groter as 0 wees.',
	invalidWidth: 'Tabelbreedte moet \'n getal wees.',
	menu: 'Tabel eienskappe',
	row: {
		menu: 'Ry',
		insertBefore: 'Voeg ry in voor',
		insertAfter: 'Voeg ry in na',
		deleteRow: 'Verwyder ry'
	},
	rows: 'Rye',
	summary: 'Opsomming',
	title: 'Tabel eienskappe',
	toolbar: 'Tabel',
	widthPc: 'persent',
	widthPx: 'piksels',
	widthUnit: 'breedte-eenheid'
} );
