/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'tt', {
	bold: 'Калын',
	italic: 'Курсив',
	strike: 'Сызылган',
	subscript: 'Аскы индекс',
	superscript: 'Өске индекс',
	underline: 'Астына сызылган'
} );
