/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'zh-cn', {
	options: '特殊符号选项',
	title: '选择特殊符号',
	toolbar: '插入特殊符号'
} );
