/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'cs', {
	border: 'Ohraničení',
	caption: 'Popis',
	cell: {
		menu: 'Buňka',
		insertBefore: 'Vložit buňku před',
		insertAfter: 'Vložit buňku za',
		deleteCell: 'Smazat buňky',
		merge: 'Sloučit buňky',
		mergeRight: 'Sloučit doprava',
		mergeDown: 'Sloučit dolů',
		splitHorizontal: 'Rozdělit buňky vodorovně',
		splitVertical: 'Rozdělit buňky svisle',
		title: 'Vlastnosti buňky',
		cellType: 'Typ buňky',
		rowSpan: 'Spojit řádky',
		colSpan: 'Spojit sloupce',
		wordWrap: 'Zalamování',
		hAlign: 'Vodorovné zarovnání',
		vAlign: 'Svislé zarovnání',
		alignBaseline: 'Na účaří',
		bgColor: 'Barva pozadí',
		borderColor: 'Barva okraje',
		data: 'Data',
		header: 'Hlavička',
		yes: 'Ano',
		no: 'Ne',
		invalidWidth: 'Šířka buňky musí být číslo.',
		invalidHeight: 'Zadaná výška buňky musí být číslená.',
		invalidRowSpan: 'Zadaný počet sloučených řádků musí být celé číslo.',
		invalidColSpan: 'Zadaný počet sloučených sloupců musí být celé číslo.',
		chooseColor: 'Výběr'
	},
	cellPad: 'Odsazení obsahu v buňce',
	cellSpace: 'Vzdálenost buněk',
	column: {
		menu: 'Sloupec',
		insertBefore: 'Vložit sloupec před',
		insertAfter: 'Vložit sloupec za',
		deleteColumn: 'Smazat sloupec'
	},
	columns: 'Sloupce',
	deleteTable: 'Smazat tabulku',
	headers: 'Záhlaví',
	headersBoth: 'Obojí',
	headersColumn: 'První sloupec',
	headersNone: 'Žádné',
	headersRow: 'První řádek',
	invalidBorder: 'Zdaná velikost okraje musí být číselná.',
	invalidCellPadding: 'Zadané odsazení obsahu v buňce musí být číselné.',
	invalidCellSpacing: 'Zadaná vzdálenost buněk musí být číselná.',
	invalidCols: 'Počet sloupců musí být číslo větší než 0.',
	invalidHeight: 'Zadaná výška tabulky musí být číselná.',
	invalidRows: 'Počet řádků musí být číslo větší než 0.',
	invalidWidth: 'Šířka tabulky musí být číslo.',
	menu: 'Vlastnosti tabulky',
	row: {
		menu: 'Řádek',
		insertBefore: 'Vložit řádek před',
		insertAfter: 'Vložit řádek za',
		deleteRow: 'Smazat řádky'
	},
	rows: 'Řádky',
	summary: 'Souhrn',
	title: 'Vlastnosti tabulky',
	toolbar: 'Tabulka',
	widthPc: 'procent',
	widthPx: 'bodů',
	widthUnit: 'jednotka šířky'
} );
