/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'image', 'he', {
	alt: 'טקסט חלופי',
	border: 'מסגרת',
	btnUpload: 'שליחה לשרת',
	button2Img: 'האם להפוך את תמונת הכפתור לתמונה פשוטה?',
	hSpace: 'מרווח אופקי',
	img2Button: 'האם להפוך את התמונה לכפתור תמונה?',
	infoTab: 'מידע על התמונה',
	linkTab: 'קישור',
	lockRatio: 'נעילת היחס',
	menu: 'תכונות התמונה',
	resetSize: 'איפוס הגודל',
	title: 'מאפייני התמונה',
	titleButton: 'מאפיני כפתור תמונה',
	upload: 'העלאה',
	urlMissing: 'כתובת התמונה חסרה.',
	vSpace: 'מרווח אנכי',
	validateBorder: 'שדה המסגרת חייב להיות מספר שלם.',
	validateHSpace: 'שדה המרווח האופקי חייב להיות מספר שלם.',
	validateVSpace: 'שדה המרווח האנכי חייב להיות מספר שלם.'
} );
