/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'pastefromword', 'tr', {
	confirmCleanup: 'Yapıştırmaya çalıştığınız metin Word\'den kopyalanmıştır. Yapıştırmadan önce silmek istermisiniz?',
	error: 'Yapıştırmadaki veri bilgisi hata düzelene kadar silinmeyecektir',
	title: 'Word\'den Yapıştır',
	toolbar: 'Word\'den Yapıştır'
} );
