/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'eu', {
	acccessKey: 'Sarbide-gakoa',
	advanced: 'Aurreratua',
	advisoryContentType: 'Eduki Mota (Content Type)',
	advisoryTitle: 'Izenburua',
	anchor: {
		toolbar: 'Aingura',
		menu: 'Ainguraren Ezaugarriak',
		title: 'Ainguraren Ezaugarriak',
		name: 'Ainguraren Izena',
		errorName: 'Idatzi ainguraren izena',
		remove: 'Remove Anchor'
	},
	anchorId: 'Elementuaren ID-gatik',
	anchorName: 'Aingura izenagatik',
	charset: 'Estekatutako Karaktere Multzoa',
	cssClasses: 'Estilo-orriko Klaseak',
	emailAddress: 'ePosta Helbidea',
	emailBody: 'Mezuaren Gorputza',
	emailSubject: 'Mezuaren Gaia',
	id: 'Id',
	info: 'Estekaren Informazioa',
	langCode: 'Hizkuntzaren Norabidea',
	langDir: 'Hizkuntzaren Norabidea',
	langDirLTR: 'Ezkerretik Eskumara(LTR)',
	langDirRTL: 'Eskumatik Ezkerrera (RTL)',
	menu: 'Aldatu Esteka',
	name: 'Izena',
	noAnchors: '(Ez daude aingurak eskuragarri dokumentuan)',
	noEmail: 'Mesedez ePosta helbidea idatzi',
	noUrl: 'Mesedez URL esteka idatzi',
	other: '<bestelakoa>',
	popupDependent: 'Menpekoa (Netscape)',
	popupFeatures: 'Popup Leihoaren Ezaugarriak',
	popupFullScreen: 'Pantaila Osoa (IE)',
	popupLeft: 'Ezkerreko  Posizioa',
	popupLocationBar: 'Kokaleku Barra',
	popupMenuBar: 'Menu Barra',
	popupResizable: 'Tamaina Aldakorra',
	popupScrollBars: 'Korritze Barrak',
	popupStatusBar: 'Egoera Barra',
	popupToolbar: 'Tresna Barra',
	popupTop: 'Goiko Posizioa',
	rel: 'Erlazioa',
	selectAnchor: 'Aingura bat hautatu',
	styles: 'Estiloa',
	tabIndex: 'Tabulazio Indizea',
	target: 'Target (Helburua)',
	targetFrame: '<marko>',
	targetFrameName: 'Marko Helburuaren Izena',
	targetPopup: '<popup leihoa>',
	targetPopupName: 'Popup Leihoaren Izena',
	title: 'Esteka',
	toAnchor: 'Aingura orrialde honetan',
	toEmail: 'ePosta',
	toUrl: 'URL',
	toolbar: 'Txertatu/Editatu Esteka',
	type: 'Esteka Mota',
	unlink: 'Kendu Esteka',
	upload: 'Gora kargatu'
} );
