/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'sl', {
	euro: 'Evro znak',
	lsquo: 'Levi enojni narekovaj',
	rsquo: 'Desni enojni narekovaj',
	ldquo: 'Levi dvojni narekovaj',
	rdquo: 'Desni dvojni narekovaj',
	ndash: 'En pomišljaj',
	mdash: 'Em pomišljaj',
	iexcl: 'Obrnjen klicaj',
	cent: 'Cent znak',
	pound: 'Funt znak',
	curren: 'Znak valute',
	yen: 'Jen znak',
	brvbar: 'Zlomljena črta',
	sect: 'Znak oddelka',
	uml: 'Diaeresis',
	copy: 'Znak avtorskih pravic',
	ordf: 'Ženski zaporedni kazalnik',
	laquo: 'Levi obrnjen dvojni kotni narekovaj',
	not: 'Ne znak',
	reg: 'Registrirani znak',
	macr: 'Macron',
	deg: 'Znak stopinj',
	sup2: 'Nadpisano dva',
	sup3: 'Nadpisano tri',
	acute: 'Ostrivec',
	micro: 'Mikro znak',
	para: 'Pilcrow znak',
	middot: 'Sredinska pika',
	cedil: 'Cedilla',
	sup1: 'Nadpisano ena',
	ordm: 'Moški zaporedni kazalnik',
	raquo: 'Desno obrnjen dvojni kotni narekovaj',
	frac14: 'Ena četrtina',
	frac12: 'Ena polovica',
	frac34: 'Tri četrtine',
	iquest: 'Obrnjen vprašaj',
	Agrave: 'Velika latinska črka A s krativcem',
	Aacute: 'Velika latinska črka A z ostrivcem',
	Acirc: 'Velika latinska črka A s strešico',
	Atilde: 'Velika latinska črka A z tildo',
	Auml: 'Velika latinska črka A z diaeresis-om',
	Aring: 'Velika latinska črka A z obročem',
	AElig: 'Velika latinska črka Æ',
	Ccedil: 'Velika latinska črka C s cedillo',
	Egrave: 'Velika latinska črka E s krativcem',
	Eacute: 'Velika latinska črka E z ostrivcem',
	Ecirc: 'Velika latinska črka E s strešico',
	Euml: 'Velika latinska črka E z diaeresis-om',
	Igrave: 'Velika latinska črka I s krativcem',
	Iacute: 'Velika latinska črka I z ostrivcem',
	Icirc: 'Velika latinska črka I s strešico',
	Iuml: 'Velika latinska črka I z diaeresis-om',
	ETH: 'Velika latinska črka Eth',
	Ntilde: 'Velika latinska črka N s tildo',
	Ograve: 'Velika latinska črka O s krativcem',
	Oacute: 'Velika latinska črka O z ostrivcem',
	Ocirc: 'Velika latinska črka O s strešico',
	Otilde: 'Velika latinska črka O s tildo',
	Ouml: 'Velika latinska črka O z diaeresis-om',
	times: 'Znak za množenje',
	Oslash: 'Velika prečrtana latinska črka O',
	Ugrave: 'Velika latinska črka U s krativcem',
	Uacute: 'Velika latinska črka U z ostrivcem',
	Ucirc: 'Velika latinska črka U s strešico',
	Uuml: 'Velika latinska črka U z diaeresis-om',
	Yacute: 'Velika latinska črka Y z ostrivcem',
	THORN: 'Velika latinska črka Thorn',
	szlig: 'Mala ostra latinska črka s',
	agrave: 'Mala latinska črka a s krativcem',
	aacute: 'Mala latinska črka a z ostrivcem',
	acirc: 'Mala latinska črka a s strešico',
	atilde: 'Mala latinska črka a s tildo',
	auml: 'Mala latinska črka a z diaeresis-om',
	aring: 'Mala latinska črka a z obročem',
	aelig: 'Mala latinska črka æ',
	ccedil: 'Mala latinska črka c s cedillo',
	egrave: 'Mala latinska črka e s krativcem',
	eacute: 'Mala latinska črka e z ostrivcem',
	ecirc: 'Mala latinska črka e s strešico',
	euml: 'Mala latinska črka e z diaeresis-om',
	igrave: 'Mala latinska črka i s krativcem',
	iacute: 'Mala latinska črka i z ostrivcem',
	icirc: 'Mala latinska črka i s strešico',
	iuml: 'Mala latinska črka i z diaeresis-om',
	eth: 'Mala latinska črka eth',
	ntilde: 'Mala latinska črka n s tildo',
	ograve: 'Mala latinska črka o s krativcem',
	oacute: 'Mala latinska črka o z ostrivcem',
	ocirc: 'Mala latinska črka o s strešico',
	otilde: 'Mala latinska črka o s tildo',
	ouml: 'Mala latinska črka o z diaeresis-om',
	divide: 'Znak za deljenje',
	oslash: 'Mala prečrtana latinska črka o',
	ugrave: 'Mala latinska črka u s krativcem',
	uacute: 'Mala latinska črka u z ostrivcem',
	ucirc: 'Mala latinska črka u s strešico',
	uuml: 'Mala latinska črka u z diaeresis-om',
	yacute: 'Mala latinska črka y z ostrivcem',
	thorn: 'Mala latinska črka thorn',
	yuml: 'Mala latinska črka y z diaeresis-om',
	OElig: 'Velika latinska ligatura OE',
	oelig: 'Mala latinska ligatura oe',
	'372': 'Velika latinska črka W s strešico',
	'374': 'Velika latinska črka Y s strešico',
	'373': 'Mala latinska črka w s strešico',
	'375': 'Mala latinska črka y s strešico',
	sbquo: 'Enojni nizki-9 narekovaj',
	'8219': 'Enojni visoki-obrnjen-9 narekovaj',
	bdquo: 'Dvojni nizki-9 narekovaj',
	hellip: 'Horizontalni izpust',
	trade: 'Znak blagovne znamke',
	'9658': 'Črni desno-usmerjen kazalec',
	bull: 'Krogla',
	rarr: 'Desno-usmerjena puščica',
	rArr: 'Desno-usmerjena dvojna puščica',
	hArr: 'Leva in desna dvojna puščica',
	diams: 'Črna kara',
	asymp: 'Skoraj enako'
} );
