/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'ug', {
	toolbarCollapse: 'قورال بالداقنى قاتلا',
	toolbarExpand: 'قورال بالداقنى ياي',
	toolbarGroups: {
		document: 'پۈتۈك',
		clipboard: 'چاپلاش تاختىسى/يېنىۋال',
		editing: 'تەھرىر',
		forms: 'جەدۋەل',
		basicstyles: 'ئاساسىي ئۇسلۇب',
		paragraph: 'ئابزاس',
		links: 'ئۇلانما',
		insert: 'قىستۇر',
		styles: 'ئۇسلۇب',
		colors: 'رەڭ',
		tools: 'قورال'
	},
	toolbars: 'قورال بالداق'
} );
