/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'wsc', 'eu', {
	btnIgnore: 'Ezikusi',
	btnIgnoreAll: 'Denak Ezikusi',
	btnReplace: 'Ordezkatu',
	btnReplaceAll: 'Denak Ordezkatu',
	btnUndo: 'Desegin',
	changeTo: 'Honekin ordezkatu',
	errorLoading: 'Errorea gertatu da aplikazioa zerbitzaritik kargatzean: %s.',
	ieSpellDownload: 'Zuzentzaile ortografikoa ez dago instalatuta. Deskargatu nahi duzu?',
	manyChanges: 'Zuzenketa ortografikoa bukatuta: %1 hitz aldatu dira',
	noChanges: 'Zuzenketa ortografikoa bukatuta: Ez da ezer aldatu',
	noMispell: 'Zuzenketa ortografikoa bukatuta: Akatsik ez',
	noSuggestions: '- Iradokizunik ez -',
	notAvailable: 'Barkatu baina momentu honetan zerbitzua ez dago erabilgarri.',
	notInDic: 'Ez dago hiztegian',
	oneChange: 'Zuzenketa ortografikoa bukatuta: Hitz bat aldatu da',
	progress: 'Zuzenketa ortografikoa martxan...',
	title: 'Ortografia zuzenketa',
	toolbar: 'Ortografia'
});
