/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'ja', {
	options: '特殊文字オプション',
	title: '特殊文字の選択',
	toolbar: '特殊文字を挿入'
} );
