/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'sk', {
	toolbarCollapse: 'Zbaliť lištu nástrojov',
	toolbarExpand: 'Rozbaliť lištu nástrojov',
	toolbarGroups: {
		document: 'Dokument',
		clipboard: 'Schránka pre kopírovanie/Späť',
		editing: 'Upravovanie',
		forms: 'Formuláre',
		basicstyles: 'Základné štýly',
		paragraph: 'Odstavec',
		links: 'Odkazy',
		insert: 'Vložiť',
		styles: 'Štýly',
		colors: 'Farby',
		tools: 'Nástroje'
	},
	toolbars: 'Lišty nástrojov editora'
} );
