/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'ar', {
	toolbarCollapse: 'تقليص شريط الأدوت',
	toolbarExpand: 'تمديد شريط الأدوات',
	toolbarGroups: {
		document: 'مستند',
		clipboard: 'الحافظة/الرجوع',
		editing: 'تحرير',
		forms: 'نماذج',
		basicstyles: 'نمط بسيط',
		paragraph: 'فقرة',
		links: 'روابط',
		insert: 'إدراج',
		styles: 'أنماط',
		colors: 'ألوان',
		tools: 'أدوات'
	},
	toolbars: 'أشرطة أدوات المحرر'
} );
