/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'pt', {
	acccessKey: 'Chave de Acesso',
	advanced: 'Avançado',
	advisoryContentType: 'Tipo de Conteúdo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: ' Inserir/Editar Âncora',
		menu: 'Propriedades da Âncora',
		title: 'Propriedades da Âncora',
		name: 'Nome da Âncora',
		errorName: 'Por favor, introduza o nome da âncora',
		remove: 'Remove Anchor'
	},
	anchorId: 'Por ID de elemento',
	anchorName: 'Por Nome de Referência',
	charset: 'Fonte de caracteres vinculado',
	cssClasses: 'Classes de Estilo de Folhas Classes',
	emailAddress: 'Endereço de E-Mail',
	emailBody: 'Corpo da Mensagem',
	emailSubject: 'Título de Mensagem',
	id: 'ID',
	info: 'Informação de Hiperligação',
	langCode: 'Orientação de idioma',
	langDir: 'Orientação de idioma',
	langDirLTR: 'Esquerda à Direita (LTR)',
	langDirRTL: 'Direita a Esquerda (RTL)',
	menu: 'Editar Hiperligação',
	name: 'Nome',
	noAnchors: '(Não há referências disponíveis no documento)',
	noEmail: 'Por favor introduza o endereço de e-mail',
	noUrl: 'Por favor introduza a hiperligação URL',
	other: '<outro>',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Características de Janela de Popup',
	popupFullScreen: 'Janela Completa (IE)',
	popupLeft: 'Posição Esquerda',
	popupLocationBar: 'Barra de localização',
	popupMenuBar: 'Barra de Menu',
	popupResizable: 'Redimensionável',
	popupScrollBars: 'Barras de deslocamento',
	popupStatusBar: 'Barra de Estado',
	popupToolbar: 'Barra de ferramentas',
	popupTop: 'Posição Direita',
	rel: 'Relação',
	selectAnchor: 'Seleccionar una referência',
	styles: 'Estilo',
	tabIndex: 'Índice de tabulação',
	target: 'Alvo',
	targetFrame: '<frame>',
	targetFrameName: 'Nome do Frame Destino',
	targetPopup: '<janela de popup>',
	targetPopupName: 'Nome da Janela de Popup',
	title: 'Hiperligação',
	toAnchor: 'Referência a esta página',
	toEmail: 'Email',
	toUrl: 'URL',
	toolbar: 'Inserir/Editar Hiperligação',
	type: 'Tipo de Hiperligação',
	unlink: 'Eliminar Hiperligação',
	upload: 'Carregar'
} );
