/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'he', {
	toolbarCollapse: 'מזעור סרגל כלים',
	toolbarExpand: 'הרחבת סרגל כלים',
	toolbarGroups: {
		document: 'מסמך',
		clipboard: 'לוח הגזירים (Clipboard)/צעד אחרון',
		editing: 'עריכה',
		forms: 'טפסים',
		basicstyles: 'עיצוב בסיסי',
		paragraph: 'פסקה',
		links: 'קישורים',
		insert: 'הכנסה',
		styles: 'עיצוב',
		colors: 'צבעים',
		tools: 'כלים'
	},
	toolbars: 'סרגלי כלים של העורך'
} );
