/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'si', {
	options: 'විශේෂ  ගුණාංග වීකල්ප',
	title: 'විශේෂ  ගුණාංග ',
	toolbar: 'විශේෂ ගුණාංග ඇතුලත් '
} );
